# Table of Contents

- [user-roles-and-permissions](<./user-roles-and-permissions.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [User Roles and Permissions](<./User-Roles-and-Permissions.md>)
  - [User Roles](<./User-Roles-and-Permissions/User-Roles.md>)
  - [Standard User Roles](<./User-Roles-and-Permissions/Standard-User-Roles.md>)
  - [Custom User Roles](<./User-Roles-and-Permissions/Custom-User-Roles.md>)
  - [Creating Custom User Roles](<./User-Roles-and-Permissions/Creating-Custom-User-Roles.md>)
  - [Role-Based Permissions](<./User-Roles-and-Permissions/Role-Based-Permissions.md>)
  - [Configuring Role-Based Permissions](<./User-Roles-and-Permissions/Configuring-Role-Based-Permissions.md>)
